{panel type="extra-for-experts" subtitle="true"}

# Extra For Experts

## Something About Love

{panel type="curiosity" title="Curiosity" summary="How is Bozo search different from Linear search?"}

# Curiosity

If you watched the video at the beginning of the chapter you might be thinking that what you did in the present searching game sounds more like Bozo Search than Linear Search, but actually Bozo Search is even sillier than this! If you were doing a Bozo Search then after unwrapping a present and finding a monster inside, you would wrap the present back up and try another one at random! This means you might end up checking the same present again and again and again and you might never find the pet, even with a small number of presents!

{panel end}
